@@ -7,12 +7,7 @@ from dangee.dangee_analysis import DangeeAanlysis
 class Dangee:
     __slots__ = [
         "ret_type",
-        "apk",
-        "dalvikvmformat",
         "analysis",
-        "all_method",
-        "native_api",
-        "self_define",
         "buff_method_set",
     ]
 
@@ -23,37 +18,16 @@ class Dangee:
 
         if self.ret_type == "APK":
             # return the APK, list of DalvikVMFormat, and Analysis objects
-            self.apk, self.dalvikvmformat, self.analysis = AnalyzeAPK(apkpath)
+            _, _, self.analysis = AnalyzeAPK(apkpath)
 
         if self.ret_type == "DEX":
             # return the sha256hash, DalvikVMFormat, and Analysis objects
             _, _, self.analysis = AnalyzeDex(apkpath)
 
-        self.all_method = set()
-        self.native_api = set()
-        self.self_define = set()
-
         for method_analysis in self.analysis.get_methods():
-
-            self.all_method.add(method_analysis)
             self.buff_method_set.add(method_analysis)
 
-            if method_analysis.is_android_api():
-                self.native_api.add(method_analysis)
-
-            if not method_analysis.is_external():
-                self.self_define.add(method_analysis)
-
-    def get_all_method(self):
-
-        return self.all_method
-
-    def get_native_method(self):
-
-        return self.native_api
-
-    def get_self_define_method(self):
-        return self.self_define
+        del _
 
     @property
     def value(self):
@@ -98,14 +72,8 @@ class Dangee:
 if __name__ == "__main__":
     # Example
 
-    d = Dangee("14d9f1a92dd984d6040cc41ed06e273e.apk")
+    d = Dangee("Roaming_Mantis.dex")
 
-    m1_data = d.match("location").isSelfDefine()
+    m1 = d.isNative().match("package").match("UsageStats")
 
-    m2_data = d.match("sendsms")
-
-    print(m1_data.value)
-
-    # print(m1_data.hasMutualParentFunctionWith(m2_data))
-
-    # print(m1_data.dataFlowto(m2_data))
+    print(m1.get_xref_from().get_xref_to().get_xref_to().value)
